package com.landray.kmss.sys.attachment.service.spring;

import com.landray.kmss.sys.filestore.location.interfaces.ISysFileLocationProxyService;
import com.landray.kmss.sys.filestore.model.SysAttFile;
import com.landray.kmss.sys.filestore.location.util.SysFileLocationUtil;
import com.landray.kmss.sys.filestore.service.ISysAttUploadService;
import com.landray.kmss.sys.attachment.model.SysAttBase;
import com.landray.kmss.sys.filestore.model.SysFileConvertQueue;
import com.landray.kmss.common.dao.HQLInfo;
import com.landray.kmss.util.ResourceUtil;
import java.util.Locale;
import com.landray.kmss.sys.attachment.util.SysAttViewerUtil;
import com.landray.kmss.sys.attachment.model.SysAttMain;
import com.landray.kmss.util.SpringBeanUtil;
import com.landray.kmss.sys.attachment.util.SysAttConfigUtil;
import java.util.Map;
import com.landray.kmss.util.StringUtil;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.List;
import com.landray.kmss.common.actions.RequestContext;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.filestore.service.ISysFileConvertQueueService;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import org.slf4j.Logger;
import com.landray.kmss.common.service.IXMLDataBean;

public class SysAttJgValidateByAsposeServiceImp implements IXMLDataBean
{
    private static final Logger logger;
    private ISysAttMainCoreInnerService sysAttMainService;
    private ISysFileConvertQueueService sysFileConvertQueueService;
    
    static {
        logger = LoggerFactory.getLogger(SysAttJgValidateByAsposeServiceImp.class);
    }
    
    public List getDataList(final RequestContext request) throws Exception {
        final List _rtnList = new ArrayList();
        final Map _rtnMap = new HashMap();
        final String fdAttMainId = request.getParameter("fdId");
        final String method = request.getParameter("method");
        if (StringUtil.isNotNull(method)) {
            final String s;
            switch (s = method) {
                case "checkIsAsposeReadOnline": {
                    _rtnMap.put("data", this.checkIsAsposeReadOnline());
                    break;
                }
                case "checkFileStatusByAttId": {
                    _rtnMap.put("data", this.checkFileStatusByAttId(fdAttMainId));
                    break;
                }
                case "checkZipFileIsConvert": {
                    _rtnMap.put("data", this.checkZipFileIsConvert(fdAttMainId));
                    break;
                }
                case "checkConvertingByAttId": {
                    _rtnMap.put("data", this.checkConvertingByAttId(fdAttMainId));
                    break;
                }
                case "isJgAndSuwell": {
                    _rtnMap.put("data", this.isJgAndSuwell());
                    break;
                }
                case "checkStrictReadPdf": {
                    final String downFlag = request.getParameter("checkFlag");
                    _rtnMap.put("data", this.checkStrictReadPdf(fdAttMainId, downFlag));
                    break;
                }
                case "getDocumentFileExt": {
                    _rtnMap.put("data", this.getDocumentFileExt(fdAttMainId));
                    break;
                }
                default:
                    break;
            }
        }
        _rtnList.add(_rtnMap);
        return _rtnList;
    }
    
    private String isJgAndSuwell() throws Exception {
        String _rtn = "false";
        final String onlineToolType = SysAttConfigUtil.getOnlineToolType();
        final String viewType = SysAttConfigUtil.getReadOLConfig();
        if ("0".equals(onlineToolType) && "9".equals(viewType)) {
            _rtn = "true";
        }
        return _rtn;
    }
    
    private ISysAttMainCoreInnerService getSysAttMainServiceImp() {
        if (this.sysAttMainService == null) {
            this.sysAttMainService = (ISysAttMainCoreInnerService)SpringBeanUtil.getBean("sysAttMainService");
        }
        return this.sysAttMainService;
    }
    
    public String checkConvertingByAttId(final String fdAttMainId) throws Exception {
        String _rtnStr = "001";
        final SysAttMain sysAttMain = (SysAttMain)this.getSysAttMainServiceImp().findByPrimaryKey(fdAttMainId);
        if (sysAttMain != null) {
            _rtnStr = SysAttViewerUtil.checkConvertingByAttId(sysAttMain);
            SysAttJgValidateByAsposeServiceImp.logger.debug("当前文件队列状态={}，转换ID={}", _rtnStr, fdAttMainId);
        }
        return _rtnStr;
    }
    
    public String checkFileStatusByAttId(final String fdAttMainId) throws Exception {
        String _rtnStr = "false";
        final SysAttMain sysAttMain = (SysAttMain)this.getSysAttMainServiceImp().findByPrimaryKey(fdAttMainId);
        if (sysAttMain != null) {
            final String fileStatus = SysAttViewerUtil.checkConvertingByAttId(sysAttMain);
            final boolean isSuccess = this.checkFileIsConvert(sysAttMain);
            SysAttJgValidateByAsposeServiceImp.logger.debug("查询附件转换队列及转换文件：文件队列状态={}，转换文件是否存在={}", fileStatus, isSuccess);
            if (4 == Integer.valueOf(fileStatus) && !isSuccess) {
                this.reDistributeQueue(sysAttMain.getFdId());
                _rtnStr = "true";
            }
            if (4 != Integer.valueOf(fileStatus) && isSuccess) {
                _rtnStr = "true";
            }
        }
        return _rtnStr;
    }
    
    public boolean checkZipFileIsConvert(final String fdAttMainId) throws Exception {
        final SysAttMain sysAttMain = (SysAttMain)this.getSysAttMainServiceImp().findByPrimaryKey(fdAttMainId);
        final boolean result = SysAttViewerUtil.checkZipFileIsConvertSuccess(sysAttMain);
        return result;
    }
    
    public String checkIsAsposeReadOnline() throws Exception {
        final String readOLConfig = SysAttConfigUtil.getReadOLConfig();
        return readOLConfig;
    }
    
    public String checkStrictReadPdf(final String fdAttMainId, final String downFlag) throws Exception {
        String _rtnStr = "false";
        final SysAttMain sysAttMain = (SysAttMain)this.getSysAttMainServiceImp().findByPrimaryKey(fdAttMainId);
        if (sysAttMain != null && StringUtil.isNotNull(sysAttMain.getFdFileName())) {
            final String fdFileName = sysAttMain.getFdFileName();
            final String _fileExtName = fdFileName.substring(fdFileName.lastIndexOf(".") + 1, fdFileName.length());
            if ("pdf".equals(_fileExtName.toLowerCase(Locale.ROOT))) {
                ResourceUtil.getKmssConfigString("iWebPDF2018");
                final boolean isReadPdf = "0".equals(SysAttConfigUtil.isReadPdf());
                final boolean isDownPdf = "1".equals(SysAttConfigUtil.isReadPdf());
                final String fdFileConvertStatus = this.checkConvertingByAttId(fdAttMainId);
                if (!String.valueOf(4).equals(fdFileConvertStatus) && isReadPdf) {
                    _rtnStr = "true";
                }
                if (!String.valueOf(4).equals(fdFileConvertStatus) && isDownPdf && StringUtil.isNotNull(downFlag)) {
                    _rtnStr = "true";
                }
            }
        }
        return _rtnStr;
    }
    
    public String getDocumentFileExt(final String fdAttMainId) throws Exception {
        String _rtnStr = "doc";
        final SysAttMain sysAttMain = (SysAttMain)this.getSysAttMainServiceImp().findByPrimaryKey(fdAttMainId);
        if (sysAttMain != null && StringUtil.isNotNull(sysAttMain.getFdFileName())) {
            final String fdFileName = sysAttMain.getFdFileName();
            _rtnStr = fdFileName.substring(fdFileName.lastIndexOf(".") + 1, fdFileName.length());
        }
        return _rtnStr.toLowerCase(Locale.ROOT);
    }
    
    private ISysFileConvertQueueService getQueueServiceImp() {
        if (this.sysFileConvertQueueService == null) {
            this.sysFileConvertQueueService = (ISysFileConvertQueueService)SpringBeanUtil.getBean("sysFileConvertQueueService");
        }
        return this.sysFileConvertQueueService;
    }
    
    public void reDistributeQueue(final String fdId) throws Exception {
        final HQLInfo info = new HQLInfo();
        info.setWhereBlock("sysFileConvertQueue.fdAttMainId='" + fdId + "'");
        final SysFileConvertQueue q = (SysFileConvertQueue)this.getQueueServiceImp().findFirstOne(info);
        if (q != null) {
            final String[] ids = q.getFdId().split(";");
            this.getQueueServiceImp().saveReDistribute("false", ids, (String[])null);
        }
    }
    
    public boolean checkFileIsConvert(final SysAttMain sysAttMain) throws Exception {
        boolean flag = false;
        if (sysAttMain.getFdFileName().endsWith("zip") || sysAttMain.getFdFileName().endsWith("rar") || sysAttMain.getFdFileName().endsWith("7z")) {
            final boolean result = flag = SysAttViewerUtil.checkZipFileIsConvertSuccess(sysAttMain);
        }
        else {
            final String attFilePath = SysAttViewerUtil.getAttFilePath((SysAttBase)sysAttMain);
            String _conStr = "_convert";
            final String location = ResourceUtil.getKmssConfigString("sys.att.location");
            if (!"server".equals(location)) {
                _conStr = String.valueOf(_conStr) + "/";
            }
            final String convertFile = String.valueOf(attFilePath) + _conStr;
            final ISysAttUploadService sysAttUploadService = (ISysAttUploadService)SpringBeanUtil.getBean("sysAttUploadService");
            final SysAttFile file = sysAttUploadService.getFileById(sysAttMain.getFdFileId());
            final ISysFileLocationProxyService proxyService = SysFileLocationUtil.getProxyService(file.getFdAttLocation());
            final String pathPrefix = (file.getFdCata() == null) ? null : file.getFdCata().getFdPath();
            flag = proxyService.doesFileExist(convertFile, pathPrefix);
            SysAttJgValidateByAsposeServiceImp.logger.debug("查询附件 : 路径={}，是否存在={}", convertFile, flag);
        }
        return flag;
    }
}
